@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2011 by Peter Semiletov                            *
+ *   Copyright (C) 2007-2012 by Peter Semiletov                            *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -44,6 +44,10 @@ code from qwriter:
 
 #include "document.h"
 #include "utils.h"
+#include "gui_utils.h"
+
+
+QSettings *settings;
 
 
 void CDocument::update_status()
@@ -55,20 +59,19 @@ void CDocument::update_status()
      }
 
   QTextBlock block = textEdit->document()->begin();
-  int cursorOffset = textEdit->textCursor().position();
+  int cursor_offset = textEdit->textCursor().position();
   
   int off = 0;
-  int x = 1;
   int y = 1;
 
-  while (cursorOffset >= (off + block.length()))
+  while (cursor_offset >= (off + block.length()))
         {
          off += block.length();
          block = block.next();
          y++;
         }
 
-  x = cursorOffset - off + 1;
+  int x = cursor_offset - off + 1;
 
   holder->l_status_bar->setText (QString ("%1:%2 %3").arg (
                                  QString::number (y)).arg (
@@ -111,7 +114,7 @@ bool CDocument::open_file (const QString &fileName, const QString &codec)
       return false;
      }
 
-  charset = codec;
+  charset = tio->charset;
   textEdit->setPlainText (tio->data);
 
   file_name = fileName;
@@ -124,6 +127,7 @@ bool CDocument::open_file (const QString &fileName, const QString &codec)
   holder->log->log (tr ("%1 is open").arg (file_name));
 
   QMutableListIterator <QString> i (holder->recent_files);
+
   while (i.hasNext())
         {
          QStringList lt = i.next().split(",");
@@ -149,9 +153,11 @@ bool CDocument::save_with_name (const QString &fileName, const QString &codec)
   if (eol_changed && (new_eol != def_eol))
       tio->data.replace ("\n", new_eol);
    
-#ifdef Q_WS_WIN   
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+
   if (! eol_changed)
       tio->data.replace ("\n", def_eol);
+
 #endif
 
   if (! tio->save (fileName))
@@ -162,7 +168,7 @@ bool CDocument::save_with_name (const QString &fileName, const QString &codec)
       return false;
      }
 
-  charset = codec;
+  charset = tio->charset;
   file_name = fileName;
 
   set_tab_caption (QFileInfo (file_name).fileName());
@@ -193,11 +199,7 @@ CDocument::CDocument (QObject *parent): QObject (parent)
   position = 0;
   eol_changed = false;
   
-#ifdef Q_WS_WIN
-
-  def_eol = "\r\n";
-
-#elif defined(Q_OS_OS2)
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
 
   def_eol = "\r\n";
 
@@ -227,7 +229,6 @@ CDocument::~CDocument()
          save_with_name (file_name, charset);
      }
 
-  if (file_name != holder->fname_crapbook)
   if (! file_name.startsWith (holder->dir_config))
      {
       holder->add_to_recent (this);
@@ -312,6 +313,19 @@ CDocument* document_holder::create_new()
 }
 
 
+CDocument* document_holder::get_document_by_fname (const QString &fileName)
+{
+  if (fileName.isNull() || fileName.isEmpty())
+     return NULL;
+
+  foreach (CDocument *d, list)
+          if (d->file_name == fileName)
+              return d;
+
+  return NULL;
+}
+
+
 CDocument* document_holder::open_file (const QString &fileName, const QString &codec)
 {
   if (! file_exists (fileName))
@@ -328,13 +342,13 @@ CDocument* document_holder::open_file (const QString &fileName, const QString &c
       return td;
      }   
    
-  foreach (CDocument *d, list)  
-          if (d->file_name == fileName)
-             {
-              tab_widget->setCurrentIndex (tab_widget->indexOf (d->tab_page));
-              return d;
-             }
-   
+  CDocument *d = get_document_by_fname (fileName);
+  if (d)
+     {
+      tab_widget->setCurrentIndex (tab_widget->indexOf (d->tab_page));
+      return d;
+     }
+
   CDocument *doc = create_new();
   doc->open_file (fileName, codec);
   doc->update_status();
@@ -474,7 +488,7 @@ void CDocument::set_hl (bool mode_auto, const QString &theext)
           textEdit->setLineWrapMode (QPlainTextEdit::NoWrap);
      }
   
-  qDebug() << "hl file is: " << fname;
+//  qDebug() << "hl file is: " << fname;
 }
 
 
@@ -638,13 +652,6 @@ void CDocument::set_markup_mode()
 }
 
 
-void CTEAEdit::dragEnterEvent (QDragEnterEvent *event)
-{
-  if (event->mimeData()->hasFormat ("text/uri-list"))
-      event->acceptProposedAction();
-}
-
-
 void CTEAEdit::cb_cursorPositionChanged()
 {
   viewport()->update();
@@ -710,26 +717,25 @@ void CTEAEdit::set_margin_pos (int mp)
 
 void CTEAEdit::paintEvent (QPaintEvent *event)
 {
-  if (draw_margin)
+  if (draw_margin || highlightCurrentLine)
      {
       QPainter painter (viewport());
 
-      QPen pen = painter.pen();
-      pen.setColor (margin_color);
-      painter.setPen (pen);
-      painter.drawLine (margin_x, 0, margin_x, viewport()->height());
-      painter.end();
-     }  
- 
-  if (highlightCurrentLine)
-     {
-      QPainter painter (viewport());
+      if (highlightCurrentLine)
+         {
+          QRect r = cursorRect();
+          r.setX (0);
+          r.setWidth (viewport()->width());
+          painter.fillRect (r, QBrush (currentLineColor));
+         }
 
-      QRect r = cursorRect();
-      r.setX (0);
-      r.setWidth (viewport()->width());
-      painter.fillRect (r, QBrush (currentLineColor));
-      painter.end();
+      if (draw_margin)
+         {
+          QPen pen = painter.pen();
+          pen.setColor (margin_color);
+          painter.setPen (pen);
+          painter.drawLine (margin_x, 0, margin_x, viewport()->height());
+         }
      }
 
   QPlainTextEdit::paintEvent (event);
@@ -738,9 +744,8 @@ void CTEAEdit::paintEvent (QPaintEvent *event)
 
 void CTEAEdit::setup_brace_width()
 {
- // QFontMetrics *fm = new QFontMetrics (currentCharFormat().font());
   QFontMetrics *fm = new QFontMetrics (font());
-  brace_width = fm->averageCharWidth(); //fm->width ("9");
+  brace_width = fm->averageCharWidth();
 }
 
 
@@ -766,29 +771,6 @@ CTEAEdit::CTEAEdit (QWidget *parent): QPlainTextEdit (parent)
 }
 
 
-void CTEAEdit::dropEvent (QDropEvent *event)
-{
-  QString fName;
-  QFileInfo info;
-
-  if (! event->mimeData()->hasUrls())
-     return;
-  
-  foreach (QUrl u, event->mimeData()->urls())
-         {
-          fName = u.toLocalFile();
-          info.setFile(fName);
-          if (info.isFile())
-             doc->holder->open_file (fName, "UTF-8");
-         }
-
-//  event->acceptProposedAction();
-//  event->accept();
-
-  QPlainTextEdit::dropEvent(event);
-}
-
-    
 QStringList CDocument::get_words()
 {
   QStringList result;
@@ -1015,12 +997,6 @@ void CSyntaxHighlighter::load_from_xml (const QString &fname)
         }
 }
 
-/*
-CTEAEdit::~CTEAEdit()
-{
-  qDebug() << "~CTEAEdit";
-}
-*/
 
 void document_holder::save_to_session (const QString &fileName)
 {
@@ -1067,33 +1043,14 @@ void document_holder::load_palette (const QString &fileName)
 }
 
 
-void CDocument::set_selected_text (const QString &value)
-{
-  textEdit->textCursor().insertText (value);
-}
-
-
 QString CDocument::get_selected_text() const
 {
   return textEdit->textCursor().selectedText();
 }
 
-
-void CDocument::set_all_text (const QString &value)
+void CDocument::set_selected_text (const QString &value)
 {
-  textEdit->setPlainText (value);
-}
-
-
-QString CDocument::get_all_text() const
-{
-  return textEdit->toPlainText();
-}
-
-
-bool CDocument::get_has_selection() const
-{
-  return textEdit->textCursor().hasSelection();
+  textEdit->textCursor().insertText (value);
 }
 
 
@@ -1205,28 +1162,28 @@ void CTEAEdit::un_indent()
 
 void CTEAEdit::keyPressEvent (QKeyEvent *event)
 {
-   if (auto_indent)
-      if (event->key() == Qt::Key_Return)
-         {
-          calc_auto_indent();
-          QPlainTextEdit::keyPressEvent (event);
-          textCursor().insertText (indent_val);
-          return;
-         }
+  if (auto_indent)
+     if (event->key() == Qt::Key_Return)
+        {
+         calc_auto_indent();
+         QPlainTextEdit::keyPressEvent (event);
+         textCursor().insertText (indent_val);
+         return;
+        }
    
-   if (event->key() == Qt::Key_Tab)
-      {
-       indent();
-       event->accept();   
-       return;
-      }
+  if (event->key() == Qt::Key_Tab)
+     {
+      indent();
+      event->accept();
+      return;
+     }
    
-   if (event->key() == Qt::Key_Backtab)
-      {
-       un_indent();
-       event->accept();   
-       return;
-      }
+  if (event->key() == Qt::Key_Backtab)
+     {
+      un_indent();
+      event->accept();
+      return;
+     }
   
   QPlainTextEdit::keyPressEvent (event);
 }
@@ -1277,19 +1234,23 @@ void CTEAEdit::lineNumberAreaPaintEvent (QPaintEvent *event)
 
   QPainter painter (lineNumberArea);
   painter.fillRect (event->rect(), linenums_bg);
+  painter.setPen (text_color);
 
   QTextBlock block = firstVisibleBlock();
   int blockNumber = block.blockNumber();
   int top = (int) blockBoundingGeometry (block).translated (contentOffset()).top();
   int bottom = top + (int) blockBoundingRect (block).height();
 
+  int w = lineNumberArea->width();
+  int h = fontMetrics().height();
+
   while (block.isValid() && top <= event->rect().bottom()) 
         {
          if (block.isVisible() && bottom >= event->rect().top()) 
             {
              QString number = QString::number (blockNumber + 1) + " ";
-             painter.setPen (text_color);
-             painter.drawText (0, top, lineNumberArea->width(), fontMetrics().height(), Qt::AlignRight, number);
+//             painter.setPen (text_color);
+             painter.drawText (0, top, w, h, Qt::AlignRight, number);
              /*int index = bookMark.indexOf(number.toInt());
  
              if (index != -1) 
@@ -1312,7 +1273,7 @@ void CTEAEdit::resizeEvent (QResizeEvent *e)
 {
   QPlainTextEdit::resizeEvent (e);
   QRect cr = contentsRect();
-  lineNumberArea->setGeometry (QRect(cr.left(), cr.top(), lineNumberAreaWidth(), cr.height()));
+  lineNumberArea->setGeometry (QRect (cr.left(), cr.top(), lineNumberAreaWidth(), cr.height()));
 }
 
 
@@ -1447,3 +1408,78 @@ void CTEAEdit::braceHighlight()
              }
      }
 }
+
+
+bool CTEAEdit::canInsertFromMimeData (const QMimeData *source)
+{
+//  if (source->hasFormat ("text/uri-list"))
+  //    return true;
+  //else
+    return true;
+}
+
+
+void CTEAEdit::insertFromMimeData (const QMimeData *source)
+{
+  qDebug()<< "CTEAEdit::insertFromMimeData ";
+
+  QString fName;
+  QFileInfo info;
+
+ // qDebug() << source->text();
+
+  bool b_ins_plain_text = ! source->hasUrls();
+  if (source->hasUrls() && source->urls().at(0).scheme() != "file")
+      b_ins_plain_text = true;
+
+  if (b_ins_plain_text)
+    {
+     QPlainTextEdit::insertFromMimeData (source);
+     return;
+    }
+
+  foreach (QUrl u, source->urls())
+         {
+          fName = u.toLocalFile();
+          info.setFile(fName);
+          if (info.isFile())
+             doc->holder->open_file (fName, "UTF-8");
+         }
+}
+
+
+QStringList text_get_bookmarks (const QString &s, const QString &sstart, const QString &send)
+{
+  QStringList result;
+
+  int c = s.size();
+  int i = 0;
+
+  while (i < c)
+        {
+         int start = s.indexOf (sstart, i, Qt::CaseInsensitive);
+
+         if (start == -1)
+             break;
+
+         int end = s.indexOf (send, start + sstart.length());
+         if (end == -1)
+             break;
+
+         result.prepend (s.mid (start + sstart.length(), (end - start) - send.length()));
+
+         i = end + 1;
+        }
+
+  return result;
+}
+
+
+
+void CDocument::update_labels()
+{
+  labels.clear();
+  labels = text_get_bookmarks (textEdit->toPlainText(),
+                                        settings->value ("label_start", "[?").toString(),
+                                        settings->value ("label_end", "?]").toString());
+}
