@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2011 by Peter Semiletov                            *
+ *   Copyright (C) 2007-2012 by Peter Semiletov                            *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -116,8 +116,9 @@ public:
 
 protected:
 
-  void dragEnterEvent (QDragEnterEvent *event);
-  void dropEvent (QDropEvent *event);
+  bool canInsertFromMimeData (const QMimeData *source);
+  void insertFromMimeData (const QMimeData *source);
+
   void paintEvent(QPaintEvent *event);
   void keyPressEvent (QKeyEvent *event);    
   void resizeEvent(QResizeEvent *event);
@@ -177,10 +178,6 @@ class CDocument: public QObject
 
 public:
 
-  Q_PROPERTY(QString selected_text READ get_selected_text WRITE set_selected_text)
-  Q_PROPERTY(QString all_text READ get_all_text WRITE set_all_text)
-  Q_PROPERTY(bool has_selection READ get_has_selection)
-
   bool cursor_xy_visible;
   bool eol_changed;
 
@@ -193,6 +190,8 @@ public:
   CSyntaxHighlighter *highlighter;
   CTEAEdit *textEdit;
 
+  QStringList labels;
+
   QString markup_mode;
   QString file_name;
   QString text_to_search;
@@ -203,12 +202,9 @@ public:
   CDocument (QObject *parent = 0);
   ~CDocument();
 
-  void set_selected_text (const QString &value);
   QString get_selected_text() const;
-  void set_all_text (const QString &value);
-  QString get_all_text() const;
-  bool get_has_selection() const;
-  
+  void set_selected_text (const QString &value);
+
   void create_new();
   void set_tab_caption (const QString &fileName);
   bool save_with_name (const QString &fileName, const QString &codec);
@@ -225,6 +221,8 @@ public:
   QString get_triplex();
   void update_status();
   void update_title (bool fullname = TRUE);
+
+  void update_labels();
 };
 
 
@@ -248,14 +246,12 @@ public:
 
   CTodo todo;
 
-
   QString markup_mode;
   QStatusBar *status_bar;
   CLogMemo *log;
   QList <CDocument*> list;
   QMainWindow *parent_wnd;
   QTabWidget *tab_widget;
-  QSettings *settings;
 
   QMenu *recent_menu;
   QStringList recent_files;
@@ -266,6 +262,8 @@ public:
   CDocument* create_new();
   CDocument* open_file (const QString &fileName, const QString &codec);
   CDocument* open_file_triplex (const QString &triplex);
+  CDocument* get_document_by_fname (const QString &fileName);
+
   void reload_recent_list();
 
   void save_to_session (const QString &fileName);
