@@ -53,12 +53,7 @@ void CFMan::nav (const QString &path)
                                          QDir::Files | QDir::Drives, QDir::Name |
                                          QDir::DirsFirst | QDir::IgnoreCase | QDir::LocaleAware);
 
-#if defined (Q_WS_WIN)
-
-  if (path != "/")
-     append_dot_entry ("..");
-
-#elif defined (Q_OS_OS2)
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
 
   if (path != "/")
      append_dot_entry ("..");
@@ -74,7 +69,7 @@ void CFMan::nav (const QString &path)
           add_entry (fi);
           
   tree_view->setModel (model);
-  connect (tree_view->selectionModel(), SIGNAL(currentChanged (const QModelIndex &, const QModelIndex &)), this, SLOT(cb_fman_currentChanged ( const QModelIndex &, const QModelIndex &)));
+  connect (tree_view->selectionModel(), SIGNAL(currentChanged (const QModelIndex &, const QModelIndex &)), this, SLOT(cb_fman_currentChanged (const QModelIndex &, const QModelIndex &)));
   emit dir_changed (path);
 }
 
@@ -214,7 +209,6 @@ void CFMan::cb_fman_currentChanged (const QModelIndex &current, const QModelInde
 
   QModelIndex i = tree_view->model()->index (row, 0);
 
-  //QString item_string = current.data().toString();
   QString item_string = i.data().toString();
 
   QString full_path = dir.path() + "/" + item_string;
