@@ -1,5 +1,5 @@
- /**************************************************************************
- *   Copyright (C) 2007-2010 by Peter Semiletov                            *
+/**************************************************************************
+ *   Copyright (C) 2007-2012 by Peter Semiletov                            *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,11 +24,10 @@
 
 
 #include <QtGui>
-#include <QtScript>
-
 
 #include "document.h"
 #include "fman.h"
+#include "calendar.h"
 #include "shortcuts.h"
 #include "img_viewer.h"
 
@@ -41,6 +40,7 @@
 
 
 
+
 class CMarkupPair: public QObject
 {
   Q_OBJECT
@@ -82,7 +82,6 @@ protected:
 public slots:
 
   void update_image();
-  
 };
 
 
@@ -119,9 +118,6 @@ public:
   QDate date1;
   QDate date2;
 
-
-  //QxtWindowSystem window_system;
-
   CScriptedApp *scripted_app;
   CLogMemo *log;
   
@@ -137,10 +133,15 @@ public:
   QString cur_spellchecker;
 
 #endif
-  
-  
+
+
+  QHash <int, QString> moon_phase_algos;
+  void create_moon_phase_algos();
+
+  int icon_size;
+
   bool b_preview;
-  bool capture_desktop;
+  bool capture_to_storage_file;
 
   int idx_tab_calendar;
   int idx_tab_edit;
@@ -154,8 +155,10 @@ public:
   QList <QStandardItem *> l_fman_find;
   
   bool ui_update;
+  QString fname_storage_file;
 
-  QScriptEngine script_engine;
+
+  //QScriptEngine script_engine;
   QHash <QString, CMarkupPair*> hs_markup;
 
   QToolBar *tb_fman_dir;
@@ -183,7 +186,7 @@ public:
   QString markup_mode;
   QPrinter printer;
 
-  QSettings *settings;
+//  QSettings *settings;
 
   QString opt_shortcuts_string_to_find;
   QString fman_fname_to_find;
@@ -201,10 +204,14 @@ public:
   QString dir_palettes;
   QString dir_tables;
   QString dir_days;
-  
+
   QString fname_def_palette;
   QString fname_hls_cache;
 
+  QString fname_userfonts;
+  QList <int> userfont_ids;
+
+
   QString fname_fif;
 
   QString fname_bookmarks;
@@ -225,6 +232,31 @@ public:
   QCheckBox *cb_show_linenums;
   QCheckBox *cb_hl_current_line;
   QCheckBox *cb_show_margin;
+  QSpinBox *spb_margin_pos;
+
+  QLineEdit *ed_label_end;
+  QLineEdit *ed_label_start;
+
+
+  QCheckBox *cb_session_restore;
+  QCheckBox *cb_use_hl_wrap;
+  QCheckBox *cb_hl_brackets;
+  QCheckBox *cb_auto_indent;
+  QCheckBox *cb_spaces_instead_of_tabs;
+  QCheckBox *cb_cursor_xy_visible;
+
+  QSpinBox *spb_tab_sp_width;
+  QCheckBox *cb_center_on_cursor;
+  QCheckBox *cb_use_trad_dialogs;
+  QCheckBox *cb_start_on_sunday;
+  QCheckBox *cb_northern_hemisphere;
+  QComboBox *cmb_moon_phase_algos;
+  QComboBox *cmb_output_image_fmt;
+  QCheckBox *cb_output_image_flt;
+
+  QSpinBox *spb_img_quality;
+  QCheckBox *cb_zip_after_scale;
+
 
 protected:
 
@@ -238,12 +270,21 @@ private slots:
 main window callbacks
 *************************/
 
+  void select_label();
+  void update_labels_menu();
+  void update_labels_list();
+
+
   void fm_full_info();
 
   void fm_hashsum_md5();
   void fm_hashsum_md4();
   void fm_hashsum_sha1();
 
+  void fman_unpack_zip();
+  void fman_zip_info();
+
+
   void fman_refresh();
   void fman_rename();
   void fman_delete();
@@ -271,6 +312,7 @@ main window callbacks
   void newFile();
   void open();
   void open_at_cursor();
+  void rename_selected();
 
   void file_reload();
   void file_reload_enc_itemDoubleClicked ( QListWidgetItem *item); 
@@ -294,14 +336,25 @@ main window callbacks
   void file_save_bak();
   void test();
 
+  void clipboard_dataChanged();
+
   void view_use_profile();
 
   void cal_set_date_a();
   void cal_set_date_b();
+  void cal_set_to_current();
+  void cal_moon_mode();
+  void cal_gen_mooncal();
+
+  void cal_diff_days();
+
 
   void cal_remove();
 
 
+  void fn_insert_cpp();
+  void fn_insert_c();
+
   bool save();
   bool saveAs();
 
@@ -323,6 +376,10 @@ main window callbacks
  
   void ed_comment();
 
+  void set_as_storage_file();
+  void copy_to_storage_file();
+  void capture_clipboard_to_storage_file();
+
   
   void upCase();
   void dnCase();
@@ -390,6 +447,7 @@ main window callbacks
 
   void fn_spell_suggest();
 
+
   void cmb_spellchecker_currentIndexChanged (const QString &text);
 
 #ifdef HUNSPELL_ENABLE
@@ -410,13 +468,9 @@ main window callbacks
   void search_in_files_results_dclicked (QListWidgetItem *item);
   void search_in_files();
 
-
   void calendar_clicked (const QDate &date);
   void calendar_activated (const QDate &date);
 
-  void cb_start_week_on_sunday_changed (int state);
-
-
   void mrkup_bold();
   void mrkup_italic();
   void mrkup_underline();
@@ -466,75 +520,23 @@ main window callbacks
 
   void fn_use_table();
 
-
-   void calendar_currentPageChanged ( int year, int month);
-
-/*************************
-prefs window callbacks
-*************************/
+  void calendar_currentPageChanged (int year, int month);
+  void add_user_font();
 
 
   void man_find_find();
   void man_find_next();
   void man_find_prev();
 
-  void cmb_output_image_fmt_currentIndexChanged (const QString &text);
-
-  
-
-  void cb_locale_override (int state);
-  void ed_locale_override_editingFinished();
-  void cb_session_restore (int state);
-  void cb_wordwrap_changed (int state);
-  void cb_hl_brackets_changed (int state);
-  void cb_use_trad_dialogs_changed (int state);
-  void cb_spaces_instead_of_tabs_changed (int state);
-  void slot_tab_sp_width_changed (int i); 
-
-  void fman_mk_gallery();
-
-  void indent_by_first_line();
 
   void profile_save_as();
-
-
-  void ed_side_size_editingFinished();
-  void ed_link_options_editingFinished();
-  void ed_cols_per_row_editingFinished();
-
-  void cb_auto_img_preview_changed (int state);
-
-  void pb_assign_hotkey_clicked();
-  void pb_remove_hotkey_clicked();
-  void slot_lv_menuitems_currentItemChanged (QListWidgetItem *current, QListWidgetItem *previous);
-  void slot_app_fontname_changed (const QString &text);
-  void slot_editor_fontname_changed (const QString &text);
-  void slot_font_size_changed (int i);
-  void cb_auto_indent_changed (int state);
-  void cb_use_hl_wrap_changed (int state);
-
-  void slot_app_font_size_changed (int i);
-  void slot_style_currentIndexChanged (const QString &text);
-  void slot_sl_icons_size_sliderMoved (int value);
-  void ed_date_format_editingFinished();
-  void ed_time_format_editingFinished();
-
-  void cb_hl_current_line_changed (int state);
-  void cb_cursor_xy_visible_changed (int state);
-  void cb_img_filter (int state);
-  void cb_img_post_proc (int state);
-  void slot_img_quality_changed (int i);
-
-  void cb_show_linenums_changed (int state);
-
-  void cb_show_margin_changed (int state);
-  void margin_pos_changed (int i);
-  void cb_cursor_center_on_scroll (int state);
+  void fman_mk_gallery();
+  void indent_by_first_line();
 
   void process_readyReadStandardOutput();
+  void fn_remove_by_regexp();
+
 
-  
-  
   void fman_naventry_confirm();
   void fman_img_conv_by_side();
   void fman_img_conv_by_percent();
@@ -549,20 +551,33 @@ prefs window callbacks
 
   void guess_enc();
 
-/*  
-  void fn_show_image_from_clipboard();
-  void fn_capture_screen();
-  void capt_active_wnd_image();
-  void capt_desktop_image();
-  void image_save_from_clipboard();
-
-
-  void screenshot_delay_changed (int i);
-*/
-
   void cal_add_days();
   void cal_add_months();
   void cal_add_years();
+
+
+/*************************
+prefs window callbacks
+*************************/
+
+  
+  void cmb_ui_tabs_currentIndexChanged (int i);
+  void cmb_docs_tabs_currentIndexChanged (int i);
+
+
+  void cmb_icon_sizes_currentIndexChanged (const QString &text);
+
+  void pb_assign_hotkey_clicked();
+  void pb_remove_hotkey_clicked();
+
+  void slot_lv_menuitems_currentItemChanged (QListWidgetItem *current, QListWidgetItem *previous);
+  void slot_app_fontname_changed (const QString &text);
+  void slot_editor_fontname_changed (const QString &text);
+  void slot_font_size_changed (int i);
+
+  void slot_app_font_size_changed (int i);
+  void slot_style_currentIndexChanged (const QString &text);
+
   
 
 private:
@@ -623,9 +638,14 @@ main window widgets
   QMenu *menu_spell_langs;
   QMenu *helpMenu;
 
+  QMenu *menu_labels;
+
+
   QToolBar *fileToolBar;
   QToolBar *editToolBar;
 
+  QAction *act_labels;
+
   QAction *act_test;
   QAction *newAct;
   QAction *openAct;
@@ -648,9 +668,11 @@ main window widgets
   QLineEdit *ed_fman_fname;
   QComboBox *cb_fman_codecs;
   QComboBox *cb_fman_drives;
+  QComboBox *cmb_spellcheckers;
+  QComboBox *cmb_styles;
+  QComboBox *cmb_icon_size;
 
-
-  QCalendarWidget *calendar;
+  CCalendarWidget *calendar;
 
 /*************************
 prefs window widgets
@@ -665,8 +687,6 @@ prefs window widgets
   QLineEdit *ed_link_options;
   QLineEdit *ed_cols_per_row;
 
-  //QSpinBox *spb_screenshot_delay;
-
 
   QLineEdit *ed_locale_override;
 
@@ -683,6 +703,13 @@ prefs window widgets
   QListWidget *lv_places;
   QSplitter *spl_fman;
 
+
+  QCheckBox *cb_auto_img_preview;
+  QCheckBox *cb_override_locale;
+
+  QComboBox *cmb_zip_charset_in;
+  QComboBox *cmb_zip_charset_out;
+
 //main window functions
 
   QAction* add_to_menu (QMenu *menu,
@@ -706,9 +733,10 @@ prefs window widgets
 
 #endif
 
-  void init_jengine();
   void handle_args();
 
+  void leaving_tune();
+
   void create_main_widget();
   void createActions();
   void createMenus();
@@ -754,7 +782,6 @@ prefs window widgets
   void count_substring (bool use_regexp);
 
   void run_unitaz (int mode);
-  void run_js_script (const QString &fname);
  
   QTextDocument::FindFlags get_search_options();
 
@@ -783,21 +810,8 @@ prefs window widgets
   void idx_tab_learn_activate();
 
   
-};
+  void load_userfonts();
 
-
-class CScriptedApp: public QObject
-{
-  Q_OBJECT
-
-public:
-
-  rvln *app; 
-
-public slots:
-
-  QString version();
-  void call_menuitem (const QString &value);
 };
 
 
@@ -813,4 +827,5 @@ public:
   void saveState (QSessionManager &manager);
 };
 
+
 #endif
