@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2010 by Peter Semiletov                            *
+ *   Copyright (C) 2007-2012 by Peter Semiletov                            *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,7 +22,6 @@
 #include <hunspell/hunspell.hxx>
 #endif
 
-
 #ifdef SPELLCHECK_ENABLE
 #include "spellchecker.h"
 #endif
@@ -38,6 +37,8 @@ CSpellchecker::CSpellchecker (const QString &lang, const QString &path,
 {
   ret = NULL;
   speller = NULL;
+
+  initialized = false;
   
   spell_config = new_aspell_config();
   if (! spell_config)
@@ -51,15 +52,11 @@ CSpellchecker::CSpellchecker (const QString &lang, const QString &path,
   QString data_path = path + "/data";
   QString dict_path = path + "/dict";
 
-  //aspell_config_replace (spell_config, "data-dir", "C:/Program Files/Aspell/data");
-  //aspell_config_replace (spell_config, "dict-dir", "C:/Program Files/Aspell/dict");
-
   aspell_config_replace (spell_config, "data-dir", data_path.toAscii().data());
   aspell_config_replace (spell_config, "dict-dir", dict_path.toAscii().data());
 
 #endif
 
-  
   ret = new_aspell_speller (spell_config);
   if (! ret)
      return;
@@ -72,6 +69,7 @@ CSpellchecker::CSpellchecker (const QString &lang, const QString &path,
      }
 
   speller = to_aspell_speller (ret);
+  initialized = true;
 }
 
 
@@ -146,10 +144,10 @@ QStringList CSpellchecker::get_speller_modules_list()
 
   while ((entry = aspell_dict_info_enumeration_next (dels)) != 0)
         {
-		 if (entry)
-           l.prepend (entry->name);
-           qDebug()	<< entry->name;	   
-		 }  
+         if (entry)
+            l.prepend (entry->name);
+         //qDebug()	<< entry->name;
+        }
 
   delete_aspell_dict_info_enumeration (dels);
 
@@ -181,14 +179,13 @@ QStringList CSpellchecker::get_suggestions_list (const QString &word)
   AspellStringEnumeration *elements = aspell_word_list_elements (suggestions);
   const char *wrd;
 
-  while (wrd = aspell_string_enumeration_next (elements))
+  while ((wrd = aspell_string_enumeration_next (elements)))
          l.prepend (QString::fromUtf8 (wrd));
 
   delete_aspell_string_enumeration (elements);
   
   return l;
 }
-
 #endif  
 
 
@@ -196,6 +193,8 @@ QStringList CSpellchecker::get_suggestions_list (const QString &word)
 
 CHunspellChecker::CHunspellChecker (const QString &lang, const QString &path, const QString &user_path): ASpellchecker (lang, path, user_path)
 {
+  initialized = false;
+
   dict_dir = path;
   user_dir = user_path; 
   lng = lang;
@@ -210,9 +209,14 @@ CHunspellChecker::CHunspellChecker (const QString &lang, const QString &path, co
   if (file_exists (fname_userdict))
      {
       speller->add_dic (fname_userdict.toUtf8().data());
-      user_words = qstring_load (fname_userdict, encoding).split ("\n");  
+      user_words = qstring_load (fname_userdict, encoding).split ("\n");
       user_words.removeFirst();
      } 
+
+  if (file_exists (fname_dict))
+      initialized = true;
+  else
+      qDebug() << "Hunspell engine is not initilized with a proper dictionary file " << fname_dict;
 }
 
 
@@ -220,17 +224,23 @@ CHunspellChecker::~CHunspellChecker()
 {
   QString filename = user_dir + "/" + lng + ".dic";
  
-  user_words.prepend (QString::number (user_words.size()));  
-  qstring_save (filename, user_words.join ("\n"), encoding);
+  if (user_words.size() > 0)
+     {
+      user_words.prepend (QString::number (user_words.size()));
+      qstring_save (filename, user_words.join ("\n"), encoding);
+     }
 
   delete speller;
+  qDebug() << "~CHunspellChecker()";
 }
 
 
 void CHunspellChecker::change_lang (const QString &lang)
 {
   delete speller;
-  
+
+  initialized = false;
+
   lng = lang;
 
   user_words.clear(); 
@@ -246,15 +256,23 @@ void CHunspellChecker::change_lang (const QString &lang)
      {
       speller->add_dic (fname_userdict.toUtf8().data());
       user_words = qstring_load (fname_userdict, encoding).split ("\n");  
-      //user_words.removeFirst();
+      user_words.removeFirst(); //зачем я это закомментировал раньше?
      } 
 
+  if (file_exists (fname_dict))
+      initialized = true;
+  else
+      qDebug() << "Hunspell engine is not initilized with a proper dictionary file " << fname_dict;
+
   qDebug() << "restarting hunspell with " << fname_aff << " " << fname_dict;
 }
 
 
 void CHunspellChecker::add_to_user_dict (const QString &word)
 {
+  if (! initialized)
+     return;
+
   QTextCodec *codec = QTextCodec::codecForName (encoding);
   QByteArray es = codec->fromUnicode (word);
   speller->add (es.data());
@@ -264,6 +282,9 @@ void CHunspellChecker::add_to_user_dict (const QString &word)
 
 bool CHunspellChecker::check (const QString &word)
 {
+  if (! initialized)
+      return false;
+
   QTextCodec *codec = QTextCodec::codecForName (encoding);
   QByteArray es = codec->fromUnicode (word);
 
@@ -273,6 +294,9 @@ bool CHunspellChecker::check (const QString &word)
 
 void CHunspellChecker::remove_from_user_dict (const QString &word)
 {
+  if (! initialized)
+      return;
+
   QTextCodec *codec = QTextCodec::codecForName (encoding);
   QByteArray es = codec->fromUnicode (word);
   speller->remove (es.data()); 
@@ -284,8 +308,11 @@ void CHunspellChecker::remove_from_user_dict (const QString &word)
 
 QStringList CHunspellChecker::get_speller_modules_list()
 {
+  if (! initialized)
+     return QStringList();
+
   QDir dir (dict_dir);
-  
+
   QStringList filters;
   QStringList sl;
   
@@ -303,6 +330,9 @@ QStringList CHunspellChecker::get_speller_modules_list()
 
 QStringList CHunspellChecker::get_suggestions_list (const QString &word)
 {
+  if (! initialized)
+     return QStringList();
+
   QStringList sl;
 
   QTextCodec *codec = QTextCodec::codecForName (encoding);
