@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2010 by Peter Semiletov                                 *
+ *   Copyright (C) 2007-2011 by Peter Semiletov                            *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -32,15 +32,16 @@
 #include <QtCore>
 
 
-class ASpellchecker//: public QObject
+class ASpellchecker
 {
-  //Q_OBJECT
 
 public:
 
+  bool initialized;
+
   ASpellchecker (const QString &lang,
-                 const QString &path = "",
-                 const QString &user_path = "") {};
+                 const QString &path,
+                 const QString &user) {};
 
   virtual ~ASpellchecker() {};
 
@@ -59,7 +60,6 @@ public:
 
 class CSpellchecker: public ASpellchecker
 {
-  //Q_OBJECT
 
 public:
 
@@ -87,7 +87,6 @@ public:
 
 class CHunspellChecker: public ASpellchecker
 {
-  //Q_OBJECT
 
 public:
 
