@@ -15,7 +15,6 @@ public:
 };
 
 
-
 class CCharsetMagic: public QObject
 {
   Q_OBJECT
@@ -31,8 +30,6 @@ public:
 };
 
 
-
-
 class CXMLWalker: public QObject
 {
   Q_OBJECT
@@ -150,6 +147,19 @@ public:
 };
 
 
+
+class CTioFB2: public CTioReadOnly
+{
+  Q_OBJECT
+
+public:
+
+  CTioFB2();
+  bool load (const QString &fname);
+};
+
+
+
 class CTioSLA: public CTioReadOnly
 {
   Q_OBJECT
