@@ -23,9 +23,14 @@ public:
    bool zip_directory (const QString &archpath, const QString &dir2pack);
    bool read_as_utf8 (const QString &archname, const QString &fname);
 
+   bool unzip (const QString &archpath, const QString &destdir);
+   QString unzip_info (const QString &archpath);
+
 signals:
 
    void new_iteration (const QFileInfo &fi);
+   void unpack_iteration (const QString &fname);
+
 };
 
 QByteArray gzip_deflateFile (const QString &fileName);
